==> idoit-1.10.zip: src/classes/modules/pro/lang/de.inc.php <==
<?php
/**
 * i-doit - Documentation and CMDB solution for IT environments
 *
 * This file is part of the i-doit framework. Modify at your own risk.
 *
 * Please visit http://www.i-doit.com/license for a full copyright and license information.
 *
 * @version     1.10
 * @package     i-doit
 * @author      synetics GmbH
 * @copyright   synetics GmbH
 * @url         http://www.i-doit.com
 * @license     http://www.i-doit.com/license
 */
/**
 * i-doit
 *
 * "Relocate-CI" Module language file
 *
 * @package     modules
 * @subpackage  relocate_ci
 * @author      Leonard Fischer <lfischer@i-doit.com>
 * @version     1.0.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.7
 */

return [
    'LC__LICENCE__TRIAL_INFO'                      => '30-tage Test Version bis zum %s',
    'LC__LICENCE_OVERVIEW__CMDB_REFERENCES'        => 'CMDB Referenzen',
    'LC__LICENCE_OVERVIEW__CURRENT_VALUE'          => 'Aktueller Wert',
    'LC__LICENCE_OVERVIEW__LICENCE_EXCEEDING'      => 'Lizenzüberschreitung',
    'LC__LICENCE_OVERVIEW__OBJECTCOUNT_BY_TYPE'    => 'Objektzähler nach Objekttyp auflisten',
    'LC__LICENCE_OVERVIEW__STATISTIC'              => 'Statistik',
    'LC__LICENCE__CHOOSE'                          => 'Lizenz auswählen',
    'LC__LICENCE__CURRENTLY_NO_LICENCES'           => 'Zur Zeit sind keine i-doit Lizenzen eingespielt',
    'LC__LICENCE__DELETED'                         => 'Lizenz wurde erfolgreich gelöscht.',
    'LC__LICENCE__DOCUMENTED_OBJECTS'              => 'Dokumentierte Objekte',
    'LC__LICENCE__ERROR_DB'                        => 'Ihr Datenbank Name "%s" entspricht nicht dem der lizenzierten Datenbank: "%s"',
    'LC__LICENCE__ERROR_KEY'                       => 'Ihr Lizenzkey ist nicht korrrekt. Die Lizenzinstallation wurde abgebrochen.',
    'LC__LICENCE__ERROR_OVERTIME'                  => 'Ihre i-doit Lizenz ist abgelaufen. Bitte updaten Sie Ihre Lizenz auf <a href="http://login.i-doit.com">login.i-doit.com</a> oder kontaktieren Sie <a href="mailto:vertrieb@i-doit.com?subject=Verlängerung der i-doit Lizenz">vertrieb@i-doit.com</a>.',
    'LC__LICENCE__ERROR_REG_DATE'                  => 'Das Registrierungsdatum der Lizenz ist höher als das aktuelle Serverdatum!',
    'LC__LICENCE__FILE'                            => 'Lizenz Datei',
    'LC__LICENCE__FREE_OBJECTS'                    => 'Freie Objekte',
    'LC__LICENCE__INSTALL'                         => 'Lizenz installieren',
    'LC__LICENCE__INSTALLED_LICENCES'              => 'Installierte Lizenzen',
    'LC__LICENCE__INSTALL_ERROR'                   => 'Fehler beim Installieren der Lizenz',
    'LC__LICENCE__INSTALL__FAIL'                   => 'Lizenz konnte nicht installiert werden',
    'LC__LICENCE__INSTALL__FAIL_EXISTS'            => 'Diese Lizenz existiert bereits',
    'LC__LICENCE__INSTALL__SUCCESSFULL'            => 'Lizenz wurde erfolgreich installiert und ist nun aktiv.',
    'LC__LICENCE__INSTALL__SUCCESSFULL__TO_EARLY'  => 'Lizenz wurde erfolgreich installiert, ist aber selbstverständlich erst ab dem %s aktiv.',
    'LC__LICENCE__LICENCED_DATABASE'               => 'Lizenzierte Datenbank',
    'LC__LICENCE__LICENCE_TYPE'                    => 'Lizenzform',
    'LC__LICENCE__MAX_AMOUNT_OF_OBJECTS'           => 'Maximale Objektanzahl',
    'LC__LICENCE__NO_LICENCE'                      => 'Achtung: Ihr i-doit ist aktuell nicht lizenziert',
    'LC__LICENCE__NO_MODULE_LICENCE'               => 'Achtung: das "%s" Modul ist aktuell nicht lizenziert',
    'LC__LICENCE__NO_UPLOAD'                       => 'Es wurde keine gültige Lizenz hochgeladen oder die PHP Datei-Upload Konfiguration ist fehlerhaft',
    'LC__LICENCE__OBJECT_COUNTER'                  => 'Objektzähler nach Objekttyp',
    'LC__LICENCE__OBJECT_COUNT_REACHED'            => 'Das Objekt Limit von %s wurde mit %s CMDB Objekten erreicht. Bitte erweitern Sie die Lizenz entsprechend.',
    'LC__LICENCE__REACH_CONCLUSION'                => 'Ihr i-doit ist nicht mehr lizensiert! Bitte kontaktieren Sie support@i-doit.org bezüglich einer Nachlizenzierung.',
    'LC__LICENCE__REGISTRATION_DATE'               => 'Registrierungsdatum',
    'LC__LICENCE__REMOVE'                          => 'Lizenz entfernen',
    'LC__LICENCE__REMOVE_CONFIRMATION'             => 'Lizenz wirklich entfernen?\\n\\nDie Lizenz ist danach nur durch erneutes Installieren wiederherstellbar.',
    'LC__LICENCE__TYPE__SUBSCRIPTION'              => 'Subskription',
    'LC__LICENCE__UPGRADE__SUCCESSFULL'            => 'Das Upgrade Ihrer bestehenden Lizenz war erfolgreich.',
    'LC__LICENCE__UPGRADE__SUCCESSFULL__TO_EARLY'  => 'Das Upgrade Ihrer bestehenden Lizenz war erfolgreich, wird aber selbstverständlich erst ab dem %s aktiv.',
    'LC__CATG__IMAGES'                             => 'Bilder',
    'LC__CATG__IMAGES__FILENAME'                   => 'Dateiname',
    'LC__CATG__IMAGES__FILECONTENT'                => 'Dateiinhalte',
    'LC__CATG__IMAGES__DELETE_IMAGE_CONFIRM'       => 'Sind Sie sicher, das Sie dieses Bild unwiderruflich löschen möchten?',
    'LC__CATG__IMAGES__DELETE_IMAGE_ERROR'         => 'Beim löschen des Bildes ist ein Fehler aufgetreten. Bitte versuchen Sie es erneut!',
    'LC__CATG__IMAGES__UPLOAD_IMAGE_ERROR'         => 'Beim hochladen des Bildes ist ein Fehler aufgetreten. Bitte versuchen Sie es erneut!',
    'LC__CATG__IMAGES__VIEW_BUTTON'                => 'Bild vergrößern (Auflösung: %s)',
    'LC__CATG__IMAGES__INFO__INNODB_LOG_FILE_SIZE' => 'Achtung! Die MySQL Konfiguration "innodb_log_file_size" sollte mindestens <code>32M</code> betragen - aktuell beträgt diese %s MB.',
    'LC__CATG__STACK_PORT_OVERVIEW'                => 'Portübersicht (Stacking)'
];

==> idoit-1.12.zip: src/classes/modules/pro/lang/de.inc.php <==
<?php
/**
 * i-doit
 *
 * "Relocate-CI" Module language file
 *
 * @package     modules
 * @subpackage  relocate_ci
 * @author      Leonard Fischer <lfischer@i-doit.com>
 * @version     1.0.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.7
 */

return [
    'LC__LICENCE__TRIAL_INFO'                      => '30-tage Test Version bis zum %s',
    'LC__LICENCE_OVERVIEW__CMDB_REFERENCES'        => 'CMDB Referenzen',
    'LC__LICENCE_OVERVIEW__CURRENT_VALUE'          => 'Aktueller Wert',
    'LC__LICENCE_OVERVIEW__LICENCE_EXCEEDING'      => 'Lizenzüberschreitung',
    'LC__LICENCE_OVERVIEW__OBJECTCOUNT_BY_TYPE'    => 'Objektzähler nach Objekttyp auflisten',
    'LC__LICENCE_OVERVIEW__STATISTIC'              => 'Statistik',
    'LC__LICENCE__CHOOSE'                          => 'Lizenz auswählen',
    'LC__LICENCE__CURRENTLY_NO_LICENCES'           => 'Zur Zeit sind keine i-doit Lizenzen eingespielt',
    'LC__LICENCE__DELETED'                         => 'Lizenz wurde erfolgreich gelöscht.',
    'LC__LICENCE__DOCUMENTED_OBJECTS'              => 'Dokumentierte Objekte',
    'LC__LICENCE__ERROR_DB'                        => 'Ihr Datenbank Name "%s" entspricht nicht dem der lizenzierten Datenbank: "%s"',
    'LC__LICENCE__ERROR_KEY'                       => 'Ihr Lizenzkey ist nicht korrrekt. Die Lizenzinstallation wurde abgebrochen.',
    'LC__LICENCE__ERROR_OVERTIME'                  => 'Ihre i-doit Lizenz ist abgelaufen. Bitte updaten Sie Ihre Lizenz auf <a href="http://login.i-doit.com">login.i-doit.com</a> oder kontaktieren Sie <a href="mailto:vertrieb@i-doit.com?subject=Verlängerung der i-doit Lizenz">vertrieb@i-doit.com</a>.',
    'LC__LICENCE__ERROR_REG_DATE'                  => 'Das Registrierungsdatum der Lizenz ist höher als das aktuelle Serverdatum!',
    'LC__LICENCE__FILE'                            => 'Lizenz Datei',
    'LC__LICENCE__FREE_OBJECTS'                    => 'Freie Objekte',
    'LC__LICENCE__INSTALL'                         => 'Lizenz installieren',
    'LC__LICENCE__INSTALLED_LICENCES'              => 'Installierte Lizenzen',
    'LC__LICENCE__INSTALL_ERROR'                   => 'Fehler beim Installieren der Lizenz',
    'LC__LICENCE__INSTALL__FAIL'                   => 'Lizenz konnte nicht installiert werden',
    'LC__LICENCE__INSTALL__FAIL_EXISTS'            => 'Diese Lizenz existiert bereits',
    'LC__LICENCE__INSTALL__SUCCESSFULL'            => 'Lizenz wurde erfolgreich installiert und ist nun aktiv.',
    'LC__LICENCE__INSTALL__SUCCESSFULL__TO_EARLY'  => 'Lizenz wurde erfolgreich installiert, ist aber selbstverständlich erst ab dem %s aktiv.',
    'LC__LICENCE__LICENCED_DATABASE'               => 'Lizenzierte Datenbank',
    'LC__LICENCE__LICENCE_TYPE'                    => 'Lizenzform',
    'LC__LICENCE__MAX_AMOUNT_OF_OBJECTS'           => 'Maximale Objektanzahl',
    'LC__LICENCE__NO_LICENCE'                      => 'Achtung: Ihr i-doit ist aktuell nicht lizenziert',
    'LC__LICENCE__NO_MODULE_LICENCE'               => 'Achtung: das "%s" Modul ist aktuell nicht lizenziert',
    'LC__LICENCE__NO_UPLOAD'                       => 'Es wurde keine gültige Lizenz hochgeladen oder die PHP Datei-Upload Konfiguration ist fehlerhaft',
    'LC__LICENCE__OBJECT_COUNTER'                  => 'Objektzähler nach Objekttyp',
    'LC__LICENCE__OBJECT_COUNT_REACHED'            => 'Das Objekt Limit von %s wurde mit %s CMDB Objekten erreicht. Bitte erweitern Sie die Lizenz entsprechend.',
    'LC__LICENCE__REACH_CONCLUSION'                => 'Ihr i-doit ist nicht mehr lizensiert! Bitte kontaktieren Sie support@i-doit.org bezüglich einer Nachlizenzierung.',
    'LC__LICENCE__REGISTRATION_DATE'               => 'Registrierungsdatum',
    'LC__LICENCE__REMOVE'                          => 'Lizenz entfernen',
    'LC__LICENCE__REMOVE_CONFIRMATION'             => 'Lizenz wirklich entfernen?\\n\\nDie Lizenz ist danach nur durch erneutes Installieren wiederherstellbar.',
    'LC__LICENCE__TYPE__SUBSCRIPTION'              => 'Subskription',
    'LC__LICENCE__UPGRADE__SUCCESSFULL'            => 'Das Upgrade Ihrer bestehenden Lizenz war erfolgreich.',
    'LC__LICENCE__UPGRADE__SUCCESSFULL__TO_EARLY'  => 'Das Upgrade Ihrer bestehenden Lizenz war erfolgreich, wird aber selbstverständlich erst ab dem %s aktiv.',
    'LC__CATG__IMAGES'                             => 'Bilder',
    'LC__CATG__IMAGES__FILENAME'                   => 'Dateiname',
    'LC__CATG__IMAGES__FILECONTENT'                => 'Dateiinhalte',
    'LC__CATG__IMAGES__DELETE_IMAGE_CONFIRM'       => 'Sind Sie sicher, das Sie dieses Bild unwiderruflich löschen möchten?',
    'LC__CATG__IMAGES__DELETE_IMAGE_ERROR'         => 'Beim löschen des Bildes ist ein Fehler aufgetreten. Bitte versuchen Sie es erneut!',
    'LC__CATG__IMAGES__UPLOAD_IMAGE_ERROR'         => 'Beim hochladen des Bildes ist ein Fehler aufgetreten. Bitte versuchen Sie es erneut!',
    'LC__CATG__IMAGES__VIEW_BUTTON'                => 'Bild vergrößern (Auflösung: %s)',
    'LC__CATG__IMAGES__INFO__INNODB_LOG_FILE_SIZE' => 'Achtung! Die MySQL Konfiguration "innodb_log_file_size" sollte mindestens <code>32M</code> betragen - aktuell beträgt diese %s MB.',
    'LC__CATG__IMAGES__ORDER_IMAGES'               => 'Bilder sortieren',
    'LC__CATG__IMAGES__SAVE_ORDER'                 => 'Reihenfolge speichern',
    'LC__CATG__STACK_PORT_OVERVIEW'                => 'Portübersicht (Stacking)'
];
